akhdefo_functions.plot_stackNetwork — akhdefo 2023 documentation

# akhdefo_functions.plot_stackNetwork

akhdefo_functions.plot_stackNetwork(src_folder='', output_folder='', cmap='tab20', date_plot_interval=(5, 30), marker_size=15)

  This Program plots temporal network of triplets to be stacked for calculating Annual Mean Velocity from stacked optical images.

  src_folder: path to georeferenced_folder

  output_folder: path to output folder to save output Figure plot

  cmap: colormap for the plot default is “tab20”

  date_plot_interval: minumum and maximum plot x axis interval dates for the plot

  marker_size: size of plotted points default is 15